@@ -76,9 +76,7 @@
 //! Lastly, errors that can be returned by the service are contained within [`error`]. [`Error`] defines a meta
 //! error encompassing all possible errors that can be returned by the service.
 //!
-//! The other modules within this crate and not required for normal usage.
-//!
-//! # Examples
+//! The other modules within this crate are not required for normal usage.
 
 // Code generated by software.amazon.smithy.rust.codegen.smithy-rs. DO NOT EDIT.
 pub use error_meta::Error;
@@ -87,7 +85,6 @@ pub use config::Config;
 
 mod aws_endpoint;
 /// Client and fluent builders for calling the service.
-#[cfg(feature = "client")]
 pub mod client;
 /// Configuration for the service.
 pub mod config;
@@ -99,6 +96,7 @@ pub mod input;
 mod json_deser;
 mod json_errors;
 mod json_ser;
+pub mod middleware;
 /// Data structures used by operation inputs/outputs.
 pub mod model;
 mod no_credentials;
@@ -121,5 +119,4 @@ pub use aws_smithy_types::retry::RetryConfig;
 pub use aws_types::app_name::AppName;
 pub use aws_types::region::Region;
 pub use aws_types::Credentials;
-#[cfg(feature = "client")]
 pub use client::Client;
